@@ -12,7 +12,7 @@ cds <- raster::setValues(raster::brick(g, g), as.matrix(xy))
 library(vdiffr)
 
 
-test_that("warning on multi laer", {
+test_that("warning on multi layer", {
   expect_warning(mesh_plot(raster::brick(g, g)), "extracting single RasterLayer")
 })
 ## can't get this to match
